@@ -315,10 +315,47 @@ def testfile(file: "Path of the file to upload",
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 
+def assemble(parent:     "Parent component identifier (ATLAS SN or alternative ID)",
+             child:      "Child component identifier (ATLAS SN or alternative ID)",
+             parentAID:  "Parent identifier is an alternative ID" = False,
+             childAID:   "Child identifier is an alternative ID" = False,
+             properties: "Properties collection (dict or .json file)" = None):
+    "Assemble a component"
+    if isinstance(properties, str) and os.path.isfile(properties):
+        logger.info(f"Loading properties from file {properties}")
+        with open(properties) as jsonFile:
+            properties = json.load(jsonFile)
+            jsonFile.close()
+    elif isinstance(properties, dict):
+        logger.info("Properties where passed as a dict")
+    elif properties is None:
+        logger.info("No properties given")
+    else:
+        logger.error(f"Unrecognised input {properties}")
+        return
+    try:
+        data = {
+            "parent": parent,
+            "child": child,
+            "alternativeIdentifierParent": parentAID,
+            "alternativeIdentifierChild": childAID,
+            "properties": properties
+        }
+        client = itkdb.Client()
+        client.post('assembleComponent', json=data)
+        logger.info(f"Assembled components {parent} and {child}")
+    except Exception as e:
+        logger.error(e)
+        logger.error(
+            f"Unable to assemble component in the DB, is the format correct?")
+
+
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
-                        attach, tests, stage, skeleton, upload, testruns, testfile])
+                        attach, tests, stage,
+                        skeleton, upload, testruns,
+                        testfile, assemble])
     parser.dispatch()
 
 
